/*
    ball-dE2.hpp - Mlut and DT computations for Euclidean distance in 2D

    Original paper and sources:
      - E. Remy and E. Thiel. Exact Medial Axis with Euclidean Distance. 
        Image and Vision Computing, 23(2):167-175, 2005. 
        https://pageperso.lis-lab.fr/edouard.thiel/IVC2004/index.html

    CC BY-SA Edouard.Thiel@univ-amu.fr, Eric.remy@univ-amu.fr - 04/08/2023
*/

#ifndef BALL_DE2_H
#define BALL_DE2_H

#include "mask-lut.hpp"


class Ball_dE2 : public MaskLut {

  public :
    void compute_CTg (int L, int *CTg) override;
    void compute_DTg (int L, int *CTg, int *DTg, int R) override;
    int get_greatest_radius (int L) override;

    int min_column_SEDT (int col[], int y, int rows);
    void compute_SEDT_Saito_Toriwaki (cv::Mat &img_int);
    int max_buffer_Saito_rev (int buf[], int pos, int cmax);
    void compute_RSEDT_Saito_Toriwaki (cv::Mat &img_int);
    void compute_level_curves (cv::Mat &img_int);

};  // class Ball_dE2


#endif // BALL_DE2_H

