/*
    ball-pack.hpp - a collection of distance balls

    CC BY-SA Edouard.Thiel@univ-amu.fr - 04/08/2023

*/

#ifndef BALL_PACK_H
#define BALL_PACK_H

#include <cstdio>
#include <iostream>
#include <vector>
#include <opencv2/opencv.hpp>
#include "ball-dW.hpp"
#include "ball-dE2.hpp"
#include "ball-dpF1.hpp"
#include "ball-dpF0.hpp"


class BallPack {
  public:
    enum DistanceId { M_D4, M_D8, M_2_3, M_3_4, M_5_7_11, M_DE2, M_DPF1, 
        M_DPF0, M_LAST };
    DistanceId current_dist_id = M_D4;

    Ball_dW  ball_d4, ball_d8, ball_d23, ball_d34, ball_d5711;
    Ball_dE2 ball_dE2;
    Ball_dpF0 ball_dpF0;
    Ball_dpF1 ball_dpF1;

    BallPack();
    static std::string get_dist_id_by_name (DistanceId dist_id);
    static DistanceId get_dist_name_by_id (std::string name);
    static std::string get_available_dist_names ();
    static DistanceId get_prev_dist_id (DistanceId dist_id);
    static DistanceId get_next_dist_id (DistanceId dist_id);
    
    std::string get_dist_name ();
    void set_prev_dist ();
    void set_next_dist ();
    
    void compute_mlutg (int L, int opt_dt);
    void compute_DT (cv::Mat &img_int);
    void compute_MA (cv::Mat &img_int);
    void compute_RDT (cv::Mat &img_int);
    void compute_level_curves (cv::Mat &img_int);

};  // class BallPack


#endif // BALL_PACK_H

